pub struct GatewayLndClient {
address: String,
tls_cert: String,
macaroon: String,
lnd_sender: Option<Sender<ForwardHtlcInterceptResponse>>,
}Fields
address: StringLND client
tls_cert: Stringmacaroon: Stringlnd_sender: Option<Sender<ForwardHtlcInterceptResponse>>Implementations
Sourceimpl GatewayLndClient
impl GatewayLndClient
pub fn new( address: String, tls_cert: String, macaroon: String, lnd_sender: Option<Sender<ForwardHtlcInterceptResponse>>, ) -> Self
async fn connect(&self) -> Result<LndClient, LightningRpcError>
Sourceasync fn spawn_lnv2_hold_invoice_subscription(
&self,
task_group: &TaskGroup,
gateway_sender: Sender<InterceptPaymentRequest>,
payment_hash: Vec<u8>,
) -> Result<(), LightningRpcError>
async fn spawn_lnv2_hold_invoice_subscription( &self, task_group: &TaskGroup, gateway_sender: Sender<InterceptPaymentRequest>, payment_hash: Vec<u8>, ) -> Result<(), LightningRpcError>
Spawns a new background task that subscribes to updates of a specific
HOLD invoice. When the HOLD invoice is ACCEPTED, we can request the
preimage from the Gateway. A new task is necessary because LND’s
global subscribe_invoices does not currently emit updates for HOLD invoices: https://github.com/lightningnetwork/lnd/issues/3120
Sourceasync fn spawn_lnv2_invoice_subscription(
&self,
task_group: &TaskGroup,
gateway_sender: Sender<InterceptPaymentRequest>,
) -> Result<(), LightningRpcError>
async fn spawn_lnv2_invoice_subscription( &self, task_group: &TaskGroup, gateway_sender: Sender<InterceptPaymentRequest>, ) -> Result<(), LightningRpcError>
Spawns a new background task that subscribes to “add” updates for all invoices. This is used to detect when a new invoice has been created. If this invoice is a HOLD invoice, it is potentially destined for a federation. At this point, we spawn a separate task to monitor the status of the HOLD invoice.
Sourceasync fn spawn_lnv1_htlc_interceptor(
&self,
task_group: &TaskGroup,
lnd_sender: Sender<ForwardHtlcInterceptResponse>,
lnd_rx: Receiver<ForwardHtlcInterceptResponse>,
gateway_sender: Sender<InterceptPaymentRequest>,
) -> Result<(), LightningRpcError>
async fn spawn_lnv1_htlc_interceptor( &self, task_group: &TaskGroup, lnd_sender: Sender<ForwardHtlcInterceptResponse>, lnd_rx: Receiver<ForwardHtlcInterceptResponse>, gateway_sender: Sender<InterceptPaymentRequest>, ) -> Result<(), LightningRpcError>
Spawns a new background task that intercepts HTLCs from the LND node. In the LNv1 protocol, this is used as a trigger mechanism for requesting the Gateway to retrieve the preimage for a payment.
Sourceasync fn spawn_interceptor(
&self,
task_group: &TaskGroup,
lnd_sender: Sender<ForwardHtlcInterceptResponse>,
lnd_rx: Receiver<ForwardHtlcInterceptResponse>,
gateway_sender: Sender<InterceptPaymentRequest>,
) -> Result<(), LightningRpcError>
async fn spawn_interceptor( &self, task_group: &TaskGroup, lnd_sender: Sender<ForwardHtlcInterceptResponse>, lnd_rx: Receiver<ForwardHtlcInterceptResponse>, gateway_sender: Sender<InterceptPaymentRequest>, ) -> Result<(), LightningRpcError>
Spawns background tasks for monitoring the status of incoming payments.
async fn cancel_htlc( key: CircuitKey, lnd_sender: Sender<ForwardHtlcInterceptResponse>, ) -> Result<(), LightningRpcError>
async fn send_lnd_response( lnd_sender: Sender<ForwardHtlcInterceptResponse>, response: ForwardHtlcInterceptResponse, ) -> Result<(), LightningRpcError>
async fn lookup_payment( &self, payment_hash: Vec<u8>, client: &mut LndClient, ) -> Result<Option<String>, LightningRpcError>
Sourceasync fn settle_hold_invoice(
&self,
payment_hash: Vec<u8>,
preimage: Preimage,
) -> Result<(), LightningRpcError>
async fn settle_hold_invoice( &self, payment_hash: Vec<u8>, preimage: Preimage, ) -> Result<(), LightningRpcError>
Settles a HOLD invoice that is specified by the payment_hash with the
given preimage. If there is no invoice corresponding to the
payment_hash, this function will return an error.
Sourceasync fn cancel_hold_invoice(
&self,
payment_hash: Vec<u8>,
) -> Result<(), LightningRpcError>
async fn cancel_hold_invoice( &self, payment_hash: Vec<u8>, ) -> Result<(), LightningRpcError>
Cancels a HOLD invoice that is specified by the payment_hash.
If there is no invoice corresponding to the payment_hash, this
function will return an error.